@@ -16,11 +16,13 @@ field_specs = {
 }
 
 
-def update_location(thng, position=None, timestamp=None, api_key=None):
+def update_location(thng, position=None, timestamp=None, api_key=None,
+                    **request_kwargs):
     data = {'position': position, 'timestamp': timestamp}
     assertions.validate_field_specs(data, field_specs)
     url = '/thngs/{}/location'.format(thng)
-    return utils.request('PUT', url, data=data, api_key=api_key)
+    return utils.request('PUT', url, data=data, api_key=api_key,
+                         **request_kwargs)
 
 
 def list_locations(thng, api_key=None, **request_kwargs):
@@ -29,7 +31,7 @@ def list_locations(thng, api_key=None, **request_kwargs):
     return utils.request('GET', url, api_key=api_key, **request_kwargs)
 
 
-def delete_location(thng, api_key=None):
+def delete_location(thng, api_key=None, **request_kwargs):
     assertions.datatype_str('thng', thng)
     url = '/thngs/{}/location'.format(thng)
-    return utils.request('DELETE', url, api_key=api_key)
+    return utils.request('DELETE', url, api_key=api_key, **request_kwargs)
